==> testsuite-1.0.6-beta1.tar.gz: testsuite/src/Form/ConfigurationForm.php <==
<?php

namespace Drupal\testsuite\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\testsuite\InitializerService;

/**
 * Defines a form that configures forms module settings.
 */
class ConfigurationForm extends ConfigFormBase {

  /**
   * @var \Drupal\testsuite\InitializerService
   */
  protected $_initializerService;

  /**
   * @param \Drupal\testsuite\InitializerService $loadResourceService
   */
  public function __construct(InitializerService $initializerService) {
    $this->_initializerService = $initializerService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('testsuite.initializer.service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'testsuite_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
        'testsuite.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('testsuite.settings');

    $form['testsuite_mysql_storage_type'] = [
        '#type' => 'radios',
        '#title' => t('Host and Db connection variables.'),
        '#options' => array(
            t('Test Suite Settings'),
            t('Drupal settings.php'),
            t('.env file')
        ),
        '#default_value' => $config->get('testsuite_mysql_storage_type') ? $config->get('testsuite_mysql_storage_type') : 0,
        '#attributes' => [
            'id' => 'test-suite-mysql-storage-type',
        ],
    ];

    $form['database'] = [
        '#type' => 'fieldset',
        '#title' => t('Host and Database Credentials'),
        '#collapsible' => FALSE,
        '#collapsed' => FALSE,
        '#states' => [
            'visible' => [
                [
                    [':input[id="test-suite-mysql-storage-type"]' => ['value' => 0]],
                    'or',
                    [':input[id="test-suite-mysql-storage-type"]' => ['value' => 2]],
                ]
            ],
        ],
    ];

    $form['database']['testsuite_simple_base_url'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('SIMPLETEST_BASE_URL'),
        '#description' => 'Example SIMPLETEST_BASE_URL<br />
            value: http://localhost',
        '#default_value' => $config->get('testsuite_simple_base_url') ? $config->get('testsuite_simple_base_url') : 'http://oig.site/',
    ];
    $form['database']['testsuite_mysql_host'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('Mysql Host'),
        '#default_value' => $config->get('testsuite_mysql_host') ? $config->get('testsuite_mysql_host') : 'localhost',
    ];
    $form['database']['testsuite_mysql_username'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('Mysql Username'),
        '#default_value' => $config->get('testsuite_mysql_username') ? $config->get('testsuite_mysql_username') : 'root',
    ];
    $form['database']['testsuite_mysql_password'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Mysql Password'),
        '#default_value' => $config->get('testsuite_mysql_password') ? $config->get('testsuite_mysql_password') : '',
    ];
    $form['database']['testsuite_mysql_port'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('Mysql Port'),
        '#default_value' => $config->get('testsuite_mysql_port') ? $config->get('testsuite_mysql_port') : '3306',
    ];
    $form['database']['testsuite_mysql_database_name'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('Mysql Database Name'),
        '#default_value' => $config->get('testsuite_mysql_database_name') ? $config->get('testsuite_mysql_database_name') : 'oig',
    ];

    $form['testsuite_browser_output_directory'] = [
        '#type' => 'textfield',
        '#title' => $this->t('BROWSERTEST_OUTPUT_DIRECTORY'),
        '#description' => 'Example BROWSERTEST_OUTPUT_DIRECTORY<br />
            value: /path/to/webroot/sites/simpletest/browser_output.<br />
            BROWSERTEST_OUTPUT_DIRECTORY is used as the directory where<br />
            the output data will be saved by PHPUnit and needs to be an<br />
            absolute local path.',
        '#default_value' => $config->get('testsuite_browser_output_directory'),
    ];

    $form['testsuite_browser_output_base_url'] = [
        '#type' => 'textfield',
        '#title' => $this->t('BROWSERTEST_OUTPUT_BASE_URL'),
        '#description' => 'By default, browser tests will output links that use the base URL set<br />
            in SIMPLETEST_BASE_URL. However, if your SIMPLETEST_BASE_URL is an internal<br />
            path (such as may be the case in a virtual or Docker-based environment),<br />
            you can set the base URL used in the browser test output links to something<br />
            reachable from your host machine here. This will allow you to follow them<br />
            directly and view the output.',
        '#default_value' => $config->get('testsuite_browser_output_base_url'),
    ];

    $form['testsuite_disable_deprecation_testing'] = [
        '#type' => 'radios',
        '#title' => $this->t('Disable deprecation testing.'),
        '#description' => 'Deprecation testing is managed through Symfony\'s PHPUnit Bridge.<br />
            The environment variable SYMFONY_DEPRECATIONS_HELPER is used to<br />
            configure the behaviour of the deprecation tests. See <a href="https://symfony.com/doc/current/components/phpunit_bridge.html#configuration" target="_blank">configuration</a><br />
            Drupal core\'s testing framework is setting this variable to its defaults.<br />
            Projects with their own requirements need to manage this variable<br />
            explicitly. To disable deprecation testing completely select yes.',
        '#options' => ['No', 'Yes'],
        '#default_value' => 0,
        '#attributes' => [
            'id' => 'test-suite-disable-deprecation',
        ],
    ];

    $form['testsuite_selectively_ignore_deprecation'] = [
        '#type' => 'radios',
        '#title' => $this->t('Selectively Ignore Deprecations'),
        '#description' => 'Deprecation errors can be selectively ignored by specifying a file of<br />
            regular expression patterns for exclusion.  See <a href="https://symfony.com/doc/current/components/phpunit_bridge.html#ignoring-deprecations" target="_blank">ignoring-deprecations</a><br />
            Select yes below to specify a custom deprecations ignore file.<br />
            NOTE: it may be required to specify the full path to the file to run tests<br />
            correctly.',
        '#options' => ['No', 'Yes'],
        '#default_value' => 0,
        '#attributes' => [
            'id' => 'test-suite-selectively-ignore-deprecation',
        ],
        '#states' => [
            'visible' => [
                ':input[id="test-suite-disable-deprecation"]' => ['value' => 0]
            ],
        ],
    ];
    $form['testsuite_selectively_ignore_deprecation_file'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Selectively Ignore Deprecations File'),
        '#default_value' => $config->get('testsuite_selectively_ignore_deprecation_file'),
        '#states' => [
          'visible' => [
            ':input[id="test-suite-disable-deprecation"]' => ['value' => 0],
            'and',
            ':input[id="test-suite-selectively-ignore-deprecation"]' => ['value' => 1],
          ],
        ],
    ];

    $form['testsuite_mink_driver_class'] = [
        '#type' => 'textfield',
        '#title' => $this->t('MINK_DRIVER_CLASS'),
        '#description' => "Example for changing the driver class for mink tests MINK_DRIVER_CLASS<br />
            value: 'Drupal\FunctionalJavascriptTests\DrupalSelenium2Driver'",
        '#default_value' => $config->get('testsuite_mink_driver_class'),
    ];

    $form['testsuite_mink_driver_args'] = [
        '#type' => 'textfield',
        '#title' => $this->t('MINK_DRIVER_ARGS'),
        '#description' => "Example for changing the driver args to mink tests<br />
            MINK_DRIVER_ARGS value: '[\"http://127.0.0.1:8510\"]",
        '#default_value' => $config->get('testsuite_mink_driver_args'),
    ];

    $form['testsuite_mink_driver_args_webdriver'] = [
        '#type' => 'textfield',
        '#title' => $this->t('MINK_DRIVER_ARGS_WEBDRIVER'),
        '#description' => "Example for changing the driver args to webdriver tests<br />
            MINK_DRIVER_ARGS_WEBDRIVER value: <br />
            '[\"chrome\", { \"chromeOptions\": { \"w3c\": false } }, \"http://localhost:4444/wd/hub\"]'<br />
            For using the Firefox browser, replace \"chrome\" with \"firefox\"",
        '#default_value' => $config->get('testsuite_mink_driver_args_webdriver'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $settings = $this->config('testsuite.settings');
    $settings->set('testsuite_mysql_storage_type', $form_state->getValue('testsuite_mysql_storage_type'))
        ->set('testsuite_simple_base_url', $form_state->getValue('testsuite_simple_base_url'))
        ->set('testsuite_mysql_host', $form_state->getValue('testsuite_mysql_host'))
        ->set('testsuite_mysql_username', $form_state->getValue('testsuite_mysql_username'))
        ->set('testsuite_mysql_port', $form_state->getValue('testsuite_mysql_port'))
        ->set('testsuite_mysql_database_name', $form_state->getValue('testsuite_mysql_database_name'))
        ->set('testsuite_mysql_password', $form_state->getValue('testsuite_mysql_password'))
        ->set('testsuite_browser_output_directory', $form_state->getValue('testsuite_browser_output_directory'))
        ->set('testsuite_browser_output_base_url', $form_state->getValue('testsuite_browser_output_base_url'))
        ->set('testsuite_disable_deprecation_testing', $form_state->getValue('testsuite_disable_deprecation_testing'))
        ->save();
    if($form_state->getValue('testsuite_selectively_ignore_deprecation') == 1) {
        $settings->set('testsuite_selectively_ignore_deprecation_file', $form_state->getValue('testsuite_selectively_ignore_deprecation_file'))->save();
    }
    $settings->set('testsuite_mink_driver_class', $form_state->getValue('testsuite_mink_driver_class'))
        ->set('testsuite_mink_driver_args', $form_state->getValue('testsuite_mink_driver_args'))
        ->set('testsuite_mink_driver_args_webdriver', $form_state->getValue('testsuite_mink_driver_args_webdriver'))
        ->save();
    parent::submitForm($form, $form_state);
  }

}

==> testsuite-1.0.14-beta1.tar.gz: testsuite/src/Form/ConfigurationForm.php <==
<?php

namespace Drupal\testsuite\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\testsuite\InitializerService;

/**
 * Defines a form that configures forms module settings.
 */
class ConfigurationForm extends ConfigFormBase {

  /**
   * @var \Drupal\testsuite\InitializerService
   */
  protected $_initializerService;

  /**
   * @var string Absolute path to browser output directory.
   */
  protected $_browserOutputDirectory;

  /**
   * @param \Drupal\testsuite\InitializerService $loadResourceService
   */
  public function __construct(InitializerService $initializerService) {
    $this->_initializerService = $initializerService;
    if($this->_initializerService->hasWebFolder()) {
        if($this->_initializerService->isWindows()) {
            $path = dirname(dirname(dirname(dirname(dirname(__DIR__)))));
            $this->_browserOutputDirectory = $path.'\sites\simpletest\browser_output';
        } else {
            $path = dirname(dirname(dirname(dirname(dirname(__DIR__)))));
            $this->_browserOutputDirectory = $path.'/sites/simpletest/browser_output';
        }
    } else {
        if($this->_initializerService->isWindows()) {
            $path = dirname(dirname(dirname(dirname(dirname(dirname(__DIR__))))));
            $this->_browserOutputDirectory = $path.'\sites\simpletest\browser_output';
        } else {
            $path = dirname(dirname(dirname(dirname(dirname(dirname(__DIR__))))));
            $this->_browserOutputDirectory = $path.'/sites/simpletest/browser_output';
        }
    }

    // dd($this->_path);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('testsuite.initializer.service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'testsuite_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
        'testsuite.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('testsuite.settings');

    $form['testsuite_mysql_storage_type'] = [
        '#type' => 'radios',
        '#title' => t('Host and Db connection variables.'),
        '#options' => array(
            t('Test Suite Settings'),
            t('Drupal settings.php'),
            t('.env file')
        ),
        '#default_value' => $config->get('testsuite_mysql_storage_type') ? $config->get('testsuite_mysql_storage_type') : 0,
        '#attributes' => [
            'id' => 'test-suite-mysql-storage-type',
        ],
    ];

    $form['database'] = [
        '#type' => 'fieldset',
        '#title' => t('Host and Database Credentials'),
        '#collapsible' => FALSE,
        '#collapsed' => FALSE,
        '#states' => [
            'visible' => [
                [
                    [':input[id="test-suite-mysql-storage-type"]' => ['value' => 0]],
                    'or',
                    [':input[id="test-suite-mysql-storage-type"]' => ['value' => 2]],
                ]
            ],
        ],
    ];

    $form['database']['testsuite_simple_base_url'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('SIMPLETEST_BASE_URL'),
        '#description' => 'Example SIMPLETEST_BASE_URL<br />
            value: http://localhost',
        '#default_value' => $config->get('testsuite_simple_base_url') ? $config->get('testsuite_simple_base_url') : 'http://oig.site/',
    ];
    $form['database']['testsuite_mysql_host'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('Mysql Host'),
        '#default_value' => $config->get('testsuite_mysql_host') ? $config->get('testsuite_mysql_host') : 'localhost',
    ];
    $form['database']['testsuite_mysql_username'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('Mysql Username'),
        '#default_value' => $config->get('testsuite_mysql_username') ? $config->get('testsuite_mysql_username') : 'root',
    ];
    $form['database']['testsuite_mysql_password'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Mysql Password'),
        '#default_value' => $config->get('testsuite_mysql_password') ? $config->get('testsuite_mysql_password') : '',
    ];
    $form['database']['testsuite_mysql_port'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('Mysql Port'),
        '#default_value' => $config->get('testsuite_mysql_port') ? $config->get('testsuite_mysql_port') : '3306',
    ];
    $form['database']['testsuite_mysql_database_name'] = [
        '#type' => 'textfield',
        '#required' => TRUE,
        '#title' => $this->t('Mysql Database Name'),
        '#default_value' => $config->get('testsuite_mysql_database_name') ? $config->get('testsuite_mysql_database_name') : 'oig',
    ];

    $form['testsuite_browser_output_directory'] = [
        '#type' => 'textfield',
        '#title' => $this->t('BROWSERTEST_OUTPUT_DIRECTORY'),
        '#description' => 'Example BROWSERTEST_OUTPUT_DIRECTORY<br />
            value: /path/to/webroot/sites/simpletest/browser_output.<br />
            BROWSERTEST_OUTPUT_DIRECTORY is used as the directory where<br />
            the output data will be saved by PHPUnit and needs to be an<br />
            absolute local path.',
        '#default_value' => $config->get('testsuite_browser_output_directory') ? $config->get('testsuite_browser_output_directory') : $this->_browserOutputDirectory,
    ];

    $form['testsuite_browser_output_base_url'] = [
        '#type' => 'textfield',
        '#title' => $this->t('BROWSERTEST_OUTPUT_BASE_URL'),
        '#description' => 'By default, browser tests will output links that use the base URL set<br />
            in SIMPLETEST_BASE_URL. However, if your SIMPLETEST_BASE_URL is an internal<br />
            path (such as may be the case in a virtual or Docker-based environment),<br />
            you can set the base URL used in the browser test output links to something<br />
            reachable from your host machine here. This will allow you to follow them<br />
            directly and view the output.',
        '#default_value' => $config->get('testsuite_browser_output_base_url'),
    ];

    $form['testsuite_disable_deprecation_testing'] = [
        '#type' => 'radios',
        '#title' => $this->t('Disable deprecation testing.'),
        '#description' => 'Deprecation testing is managed through Symfony\'s PHPUnit Bridge.<br />
            The environment variable SYMFONY_DEPRECATIONS_HELPER is used to<br />
            configure the behaviour of the deprecation tests. See <a href="https://symfony.com/doc/current/components/phpunit_bridge.html#configuration" target="_blank">configuration</a><br />
            Drupal core\'s testing framework is setting this variable to its defaults.<br />
            Projects with their own requirements need to manage this variable<br />
            explicitly. To disable deprecation testing completely select yes.',
        '#options' => ['No', 'Yes'],
        '#default_value' => 0,
        '#attributes' => [
            'id' => 'test-suite-disable-deprecation',
        ],
    ];

    $form['testsuite_selectively_ignore_deprecation'] = [
        '#type' => 'radios',
        '#title' => $this->t('Selectively Ignore Deprecations'),
        '#description' => 'Deprecation errors can be selectively ignored by specifying a file of<br />
            regular expression patterns for exclusion.  See <a href="https://symfony.com/doc/current/components/phpunit_bridge.html#ignoring-deprecations" target="_blank">ignoring-deprecations</a><br />
            Select yes below to specify a custom deprecations ignore file.<br />
            NOTE: it may be required to specify the full path to the file to run tests<br />
            correctly.',
        '#options' => ['No', 'Yes'],
        '#default_value' => 0,
        '#attributes' => [
            'id' => 'test-suite-selectively-ignore-deprecation',
        ],
        '#states' => [
            'visible' => [
                ':input[id="test-suite-disable-deprecation"]' => ['value' => 0]
            ],
        ],
    ];

    $form['testsuite_selectively_ignore_deprecation_file'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Selectively Ignore Deprecations File'),
        '#default_value' => $config->get('testsuite_selectively_ignore_deprecation_file'),
        '#states' => [
          'visible' => [
            ':input[id="test-suite-disable-deprecation"]' => ['value' => 0],
            'and',
            ':input[id="test-suite-selectively-ignore-deprecation"]' => ['value' => 1],
          ],
        ],
    ];

    $form['testsuite_mink_driver_class'] = [
        '#type' => 'textfield',
        '#title' => $this->t('MINK_DRIVER_CLASS'),
        '#description' => "Example for changing the driver class for mink tests MINK_DRIVER_CLASS<br />
            value: 'Drupal\FunctionalJavascriptTests\DrupalSelenium2Driver'",
        '#default_value' => $config->get('testsuite_mink_driver_class'),
    ];

    $form['testsuite_mink_driver_args'] = [
        '#type' => 'textfield',
        '#title' => $this->t('MINK_DRIVER_ARGS'),
        '#description' => "Example for changing the driver args to mink tests<br />
            MINK_DRIVER_ARGS value: '[\"http://127.0.0.1:8510\"]",
        '#default_value' => $config->get('testsuite_mink_driver_args'),
    ];

    $form['testsuite_mink_driver_args_webdriver'] = [
        '#type' => 'textfield',
        '#title' => $this->t('MINK_DRIVER_ARGS_WEBDRIVER'),
        '#description' => "Example for changing the driver args to webdriver tests<br />
            MINK_DRIVER_ARGS_WEBDRIVER value: <br />
            '[\"chrome\", { \"chromeOptions\": { \"w3c\": false } }, \"http://localhost:4444/wd/hub\"]'<br />
            For using the Firefox browser, replace \"chrome\" with \"firefox\"",
        '#default_value' => $config->get('testsuite_mink_driver_args_webdriver'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $settings = $this->config('testsuite.settings');
    $settings->set('testsuite_mysql_storage_type', $form_state->getValue('testsuite_mysql_storage_type'))
        ->set('testsuite_simple_base_url', $form_state->getValue('testsuite_simple_base_url'))
        ->set('testsuite_mysql_host', $form_state->getValue('testsuite_mysql_host'))
        ->set('testsuite_mysql_username', $form_state->getValue('testsuite_mysql_username'))
        ->set('testsuite_mysql_port', $form_state->getValue('testsuite_mysql_port'))
        ->set('testsuite_mysql_database_name', $form_state->getValue('testsuite_mysql_database_name'))
        ->set('testsuite_mysql_password', $form_state->getValue('testsuite_mysql_password'))
        ->set('testsuite_browser_output_directory', $form_state->getValue('testsuite_browser_output_directory'))
        ->set('testsuite_browser_output_base_url', $form_state->getValue('testsuite_browser_output_base_url'))
        ->set('testsuite_disable_deprecation_testing', $form_state->getValue('testsuite_disable_deprecation_testing'))
        ->save();
    if($form_state->getValue('testsuite_selectively_ignore_deprecation') == 1) {
        $settings->set('testsuite_selectively_ignore_deprecation_file', $form_state->getValue('testsuite_selectively_ignore_deprecation_file'))->save();
    }
    $settings->set('testsuite_mink_driver_class', $form_state->getValue('testsuite_mink_driver_class'))
        ->set('testsuite_mink_driver_args', $form_state->getValue('testsuite_mink_driver_args'))
        ->set('testsuite_mink_driver_args_webdriver', $form_state->getValue('testsuite_mink_driver_args_webdriver'))
        ->save();
    parent::submitForm($form, $form_state);
  }
}
